.. dns_sprockets documentation master file, created by
   sphinx-quickstart on Mon Jul  6 15:51:06 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.rst

.. toctree::
   :maxdepth: 2


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


.. include:: ../CHANGES.txt

.. include:: ../AUTHORS.txt

.. include:: ../COPYRIGHT.txt
